@@ -151,11 +151,11 @@ def create_full_spm_subpipes(
     seg_pipe.connect(inputnode, ('indiv_params', parse_key, "debias"),
                      debias, 'indiv_params')
 
-    if 'bet_crop' in parse_key(params, "short_preparation_pipe"):
+    if 'crop_T1' in parse_key(params, "short_preparation_pipe"):
+        debias.inputs.bet = 1
+    else:
         seg_pipe.connect(data_preparation_pipe, 'bet_crop.mask_file',
                          debias, 'b')
-    else:
-        debias.inputs.bet = 1
 
     if pad:
 
@@ -1203,7 +1203,8 @@ def create_brain_extraction_T1_pipe(params_template, params={},
 
 
 def create_brain_segment_from_mask_T1_pipe(
-        params_template, params={}, name="brain_segment_from_mask_T1_pipe"):
+        params_template, params={}, name="brain_segment_from_mask_T1_pipe",
+        space="native"):
     """
     Description: Segment T1 from a previously computed mask.
 
@@ -1292,107 +1293,56 @@ def create_brain_segment_from_mask_T1_pipe(
     brain_segment_pipe.connect(register_NMT_pipe, 'align_seg_wm.out_file',
                                segment_atropos_pipe, "inputnode.wm_prior_file")
 
-    return brain_segment_pipe
-
-
-def create_brain_segment_from_mask_T1_template_pipe(
-        params_template, params={},
-        name="brain_segment_from_mask_T1_template_pipe"):
-    """
-    Description: Segment T1 from a previously computed mask.
-
-    Params:
-
-    - register_NMT_pipe (see :class:`create_register_NMT_pipe \
-    <macapype.pipelines.register.create_register_NMT_pipe>`)
-    - segment_atropos_pipe (see :class:`create_segment_atropos_pipe \
-    <macapype.pipelines.segment.create_segment_atropos_pipe>`)
-
-    Inputs:
-
-        inputnode:
-
-            preproc_T1:
-                preprocessed T1 file name
-
-            brain_mask:
-                a mask computed for the same T1/T2 images
-
-            indiv_params (opt):
-                dict with individuals parameters for some nodes
-
-
-        arguments:
-
-            params_template:
-                dictionary of template files
-
-            params:
-                dictionary of node sub-parameters (from a json file)
-
-            name:
-                pipeline name (default = "full_segment_pipe")
-
-    Outputs:
-
-    """
-    # creating pipeline
-    brain_segment_pipe = pe.Workflow(name=name)
-
-    # creating inputnode
-    inputnode = pe.Node(
+    outputnode = pe.Node(
         niu.IdentityInterface(
-            fields=['preproc_T1', 'brain_mask', 'indiv_params']),
-        name='inputnode')
+            fields=["segmented_file", "threshold_gm", "threshold_wm",
+                    "threshold_csf"]),
+        name='outputnode')
 
-    # mask T1 using brain mask and perform N4 bias correction
+    if space == 'native':
 
-    # restore_mask_T1
-    restore_mask_T1 = pe.Node(fsl.ApplyMask(), name='restore_mask_T1')
+        brain_segment_pipe.connect(segment_atropos_pipe,
+                                   'outputnode.segmented_file',
+                                   outputnode, 'segmented_file')
+        brain_segment_pipe.connect(segment_atropos_pipe,
+                                   'outputnode.threshold_gm',
+                                   outputnode, 'threshold_gm')
+        brain_segment_pipe.connect(segment_atropos_pipe,
+                                   'outputnode.threshold_wm',
+                                   outputnode, 'threshold_wm')
+        brain_segment_pipe.connect(segment_atropos_pipe,
+                                   'outputnode.threshold_csf',
+                                   outputnode, 'threshold_csf')
 
-    brain_segment_pipe.connect(inputnode, 'preproc_T1',
-                               restore_mask_T1, 'in_file')
-    brain_segment_pipe.connect(inputnode, 'brain_mask',
-                               restore_mask_T1, 'mask_file')
+    else:
+        reg_seg_pipe = create_reg_seg_pipe()
 
-    NMT_version = "v1.3"
+        brain_segment_pipe.connect(segment_atropos_pipe,
+                                   'outputnode.segmented_file', reg_seg_pipe,
+                                   'inputnode.native_segmented_file')
 
-    print("NMT_version:", NMT_version)
+        brain_segment_pipe.connect(register_NMT_pipe,
+                                   'NMT_subject_align.transfo_file',
+                                   reg_seg_pipe, 'inputnode.transfo_file')
 
-    # register NMT template, template mask and priors to subject T1
-    register_NMT_pipe = create_register_NMT_pipe(
-        params_template=params_template,
-        params=parse_key(params, "register_NMT_pipe"), NMT_version=NMT_version)
+        reg_seg_pipe.inputs.inputnode.ref_image = \
+            params_template['template_head']
 
-    brain_segment_pipe.connect(
-        restore_mask_T1, 'out_file',
-        register_NMT_pipe, "inputnode.T1")
-    brain_segment_pipe.connect(
-        inputnode, 'indiv_params',
-        register_NMT_pipe, "inputnode.indiv_params")
-
-    # ants Atropos
-    segment_atropos_pipe = create_segment_atropos_pipe(
-        params=parse_key(params, "segment_atropos_template_pipe"))
-
-    brain_segment_pipe.connect(
-        register_NMT_pipe, 'NMT_subject_align.aff_file',
-        segment_atropos_pipe, "inputnode.brain_file")
-
-    segment_atropos_pipe.inputs.inputnode.csf_prior_file = \
-        params_template["template_csf"],
-
-    segment_atropos_pipe.inputs.inputnode.gm_prior_file = \
-        params_template["template_gm"]
-
-    segment_atropos_pipe.inputs.inputnode.wm_prior_file = \
-        params_template["template_wm"]
+        brain_segment_pipe.connect(reg_seg_pipe, 'outputnode.norm_seg',
+                                   outputnode, 'segmented_file')
+        brain_segment_pipe.connect(reg_seg_pipe, 'outputnode.norm_gm',
+                                   outputnode, 'threshold_gm')
+        brain_segment_pipe.connect(reg_seg_pipe, 'outputnode.norm_wm',
+                                   outputnode, 'threshold_wm')
+        brain_segment_pipe.connect(reg_seg_pipe, 'outputnode.norm_csf',
+                                   outputnode, 'threshold_csf')
 
     return brain_segment_pipe
 
 
 def create_full_T1_ants_subpipes(params_template, params={},
-                                 name="full_T1_ants_subpipes", space="native"):
+                                 name="full_T1_ants_subpipes", space="native",
+                                 pad=False):
 
     """Description: Full pipeline to segment T1 (with no T2).
 
@@ -1485,56 +1435,45 @@ def create_full_T1_ants_subpipes(params_template, params={},
             skipping")
         return seg_pipe
 
-    if space == "native":
+    brain_segment_pipe = create_brain_segment_from_mask_T1_pipe(
+        params_template=params_template,
+        params=parse_key(params, "brain_segment_pipe"), space=space)
 
-        brain_segment_pipe = create_brain_segment_from_mask_T1_pipe(
-            params_template=params_template,
-            params=parse_key(params, "brain_segment_pipe"))
+    seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
+                        brain_segment_pipe, 'inputnode.preproc_T1')
+    seg_pipe.connect(brain_extraction_pipe,
+                        "extract_T1_pipe.smooth_mask.out_file",
+                        brain_segment_pipe, "inputnode.brain_mask")
+    seg_pipe.connect(inputnode, 'indiv_params',
+                        brain_segment_pipe, 'inputnode.indiv_params')
 
-        seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
-                         brain_segment_pipe, 'inputnode.preproc_T1')
-        seg_pipe.connect(brain_extraction_pipe,
-                         "extract_T1_pipe.smooth_mask.out_file",
-                         brain_segment_pipe, "inputnode.brain_mask")
-        seg_pipe.connect(inputnode, 'indiv_params',
-                         brain_segment_pipe, 'inputnode.indiv_params')
+    if pad and space == "native":
 
-    elif space == "template":
+        print("Padding seg mask in native space")
 
-        brain_segment_pipe = create_brain_segment_from_mask_T1_template_pipe(
-            params_template=params_template,
-            params=parse_key(params, "brain_segment_pipe"))
+        pad_seg_mask = pe.Node(
+            niu.Function(
+                input_names=['cropped_img_file', 'orig_img_file',
+                             'indiv_crop'],
+                output_names=['padded_img_file'],
+                function=padding_cropped_img),
+            name="pad_seg_mask")
 
-        seg_pipe.connect(data_preparation_pipe, 'outputnode.preproc_T1',
-                         brain_segment_pipe, 'inputnode.preproc_T1')
-        seg_pipe.connect(brain_extraction_pipe,
-                         "extract_T1_pipe.smooth_mask.out_file",
-                         brain_segment_pipe, "inputnode.brain_mask")
-        seg_pipe.connect(inputnode, 'indiv_params',
-                         brain_segment_pipe, 'inputnode.indiv_params')
+        seg_pipe.connect(brain_segment_pipe, 'outputnode.segmented_file',
+                         pad_seg_mask, "cropped_img_file")
 
-    if "mask_from_seg_pipe" in params.keys():
-        mask_from_seg_pipe = create_mask_from_seg_pipe(
-            params=parse_key(params, "mask_from_seg_pipe"))
+        seg_pipe.connect(data_preparation_pipe, "av_T1.avg_img",
+                         pad_seg_mask, "orig_img_file")
 
-        seg_pipe.connect(brain_segment_pipe,
-                         'segment_atropos_pipe.outputnode.threshold_csf',
-                         mask_from_seg_pipe, 'inputnode.mask_csf')
+        seg_pipe.connect(inputnode, "indiv_params", pad_seg_mask, "indiv_crop")
 
-        seg_pipe.connect(brain_segment_pipe,
-                         'segment_atropos_pipe.outputnode.threshold_wm',
-                         mask_from_seg_pipe, 'inputnode.mask_wm')
-
-        seg_pipe.connect(brain_segment_pipe,
-                         'segment_atropos_pipe.outputnode.threshold_gm',
-                         mask_from_seg_pipe, 'inputnode.mask_gm')
-
-        seg_pipe.connect(inputnode, 'indiv_params',
-                         mask_from_seg_pipe, 'inputnode.indiv_params')
-
-        seg_pipe.connect(mask_from_seg_pipe, 'merge_indexed_mask.indexed_mask',
+        seg_pipe.connect(pad_seg_mask, "padded_img_file",
+                         outputnode, "segmented_brain_mask")
+    else:
+        seg_pipe.connect(brain_segment_pipe, 'outputnode.segmented_file',
                          outputnode, 'segmented_brain_mask')
 
+
     if "nii_to_mesh_fs_pipe" in params.keys():
         nii_to_mesh_fs_pipe = create_nii_to_mesh_fs_pipe(
             params=parse_key(params, "nii_to_mesh_fs_pipe"))
